@@ -195,16 +195,20 @@ function configure_trove {
 
     # Create the trove conf dir and cache dirs if they don't exist
     sudo install -d -o $STACK_USER ${TROVE_CONF_DIR}
-
     # Copy api-paste file over to the trove conf dir
     cp $TROVE_LOCAL_API_PASTE_INI $TROVE_API_PASTE_INI
-
+    # configure apache related files
+    if [[ "${TROVE_USE_MOD_WSGI}" == "TRUE" ]]; then
+        echo "Configuring Trove to use mod-wsgi and Apache"
+        config_trove_apache_wsgi
+    fi
     # (Re)create trove conf files
     rm -f $TROVE_CONF $TROVE_GUESTAGENT_CONF
 
     TROVE_AUTH_ENDPOINT=$KEYSTONE_AUTH_URI/v$IDENTITY_API_VERSION
 
-    # Set common configuration values (but only if they're defined)
+    ################################################################ trove conf
+    setup_trove_logging $TROVE_CONF
     iniset_conditional $TROVE_CONF DEFAULT max_accepted_volume_size $TROVE_MAX_ACCEPTED_VOLUME_SIZE
     iniset_conditional $TROVE_CONF DEFAULT max_instances_per_tenant $TROVE_MAX_INSTANCES_PER_TENANT
     iniset_conditional $TROVE_CONF DEFAULT max_volumes_per_tenant $TROVE_MAX_VOLUMES_PER_TENANT
@@ -213,34 +217,26 @@ function configure_trove {
     iniset_conditional $TROVE_CONF DEFAULT resize_time_out $TROVE_RESIZE_TIME_OUT
     iniset_conditional $TROVE_CONF DEFAULT usage_timeout $TROVE_USAGE_TIMEOUT
     iniset_conditional $TROVE_CONF DEFAULT state_change_wait_time $TROVE_STATE_CHANGE_WAIT_TIME
+    iniset_conditional $TROVE_CONF DEFAULT reboot_time_out 300
+
+    configure_keystone_authtoken_middleware $TROVE_CONF trove
+    iniset $TROVE_CONF service_credentials username trove
+    iniset $TROVE_CONF service_credentials user_domain_name Default
+    iniset $TROVE_CONF service_credentials project_domain_name Default
+    iniset $TROVE_CONF service_credentials password $SERVICE_PASSWORD
+    iniset $TROVE_CONF service_credentials project_name $SERVICE_PROJECT_NAME
+    iniset $TROVE_CONF service_credentials region_name $REGION_NAME
+    iniset $TROVE_CONF service_credentials auth_url $TROVE_AUTH_ENDPOINT
+
+    iniset $TROVE_CONF database connection `database_connection_url trove`
 
-    # For message queue
     iniset $TROVE_CONF DEFAULT rpc_backend "rabbit"
     iniset $TROVE_CONF DEFAULT control_exchange trove
     iniset $TROVE_CONF DEFAULT transport_url rabbit://$RABBIT_USERID:$RABBIT_PASSWORD@$RABBIT_HOST:5672/
-    # For database
-    iniset $TROVE_CONF database connection `database_connection_url trove`
-    # For logging
-    setup_trove_logging $TROVE_CONF
-
     iniset $TROVE_CONF DEFAULT trove_api_workers "$API_WORKERS"
-    configure_keystone_authtoken_middleware $TROVE_CONF trove
-
     iniset $TROVE_CONF DEFAULT taskmanager_manager trove.taskmanager.manager.Manager
-
-    iniset $TROVE_CONF DEFAULT trove_auth_url $TROVE_AUTH_ENDPOINT
-    iniset $TROVE_CONF DEFAULT nova_proxy_admin_user trove
-    iniset $TROVE_CONF DEFAULT nova_proxy_admin_tenant_name $SERVICE_PROJECT_NAME
-    iniset $TROVE_CONF DEFAULT nova_proxy_admin_pass $SERVICE_PASSWORD
-    iniset $TROVE_CONF DEFAULT nova_proxy_admin_user_domain_name default
-    iniset $TROVE_CONF DEFAULT nova_proxy_admin_project_domain_name default
-    iniset $TROVE_CONF DEFAULT os_region_name $REGION_NAME
-    iniset $TROVE_CONF DEFAULT remote_nova_client trove.common.single_tenant_remote.nova_client_trove_admin
-    iniset $TROVE_CONF DEFAULT remote_cinder_client trove.common.single_tenant_remote.cinder_client_trove_admin
-    iniset $TROVE_CONF DEFAULT remote_neutron_client trove.common.single_tenant_remote.neutron_client_trove_admin
-    iniset $TROVE_CONF DEFAULT remote_swift_client trove.common.single_tenant_remote.swift_client_trove_admin
-
     iniset $TROVE_CONF DEFAULT default_datastore $TROVE_DATASTORE_TYPE
+
     iniset $TROVE_CONF cassandra tcp_ports 7000,7001,7199,9042,9160
     iniset $TROVE_CONF couchbase tcp_ports 8091,8092,4369,11209-11211,21100-21199
     iniset $TROVE_CONF couchdb tcp_ports 5984
@@ -254,44 +250,45 @@ function configure_trove {
     iniset $TROVE_CONF redis tcp_ports 6379,16379
     iniset $TROVE_CONF vertica tcp_ports 5433,5434,5444,5450,4803
 
-    # configure apache related files
-    if [[ "${TROVE_USE_MOD_WSGI}" == "TRUE" ]]; then
-        echo "Configuring Trove to use mod-wsgi and Apache"
-        config_trove_apache_wsgi
-    fi
+    ################################################################ trove guest agent conf
+    setup_trove_logging $TROVE_GUESTAGENT_CONF
 
-    # Use these values only if they're set
     iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT state_change_wait_time $TROVE_STATE_CHANGE_WAIT_TIME
     iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT command_process_timeout $TROVE_COMMAND_PROCESS_TIMEOUT
-
-    # Set up Guest Agent conf
     iniset $TROVE_GUESTAGENT_CONF DEFAULT rpc_backend "rabbit"
     iniset $TROVE_GUESTAGENT_CONF DEFAULT transport_url rabbit://$RABBIT_USERID:$RABBIT_PASSWORD@$TROVE_HOST_GATEWAY:5672/
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT trove_auth_url $TROVE_AUTH_ENDPOINT
     iniset $TROVE_GUESTAGENT_CONF DEFAULT control_exchange trove
     iniset $TROVE_GUESTAGENT_CONF DEFAULT ignore_users os_admin
     iniset $TROVE_GUESTAGENT_CONF DEFAULT log_dir /var/log/trove/
     iniset $TROVE_GUESTAGENT_CONF DEFAULT log_file trove-guestagent.log
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT nova_proxy_admin_user trove
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT nova_proxy_admin_tenant_name $SERVICE_PROJECT_NAME
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT nova_proxy_admin_pass $SERVICE_PASSWORD
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT nova_proxy_admin_user_domain_name default
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT nova_proxy_admin_project_domain_name default
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT os_region_name $REGION_NAME
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT remote_nova_client trove.common.single_tenant_remote.nova_client_trove_admin
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT remote_cinder_client trove.common.single_tenant_remote.cinder_client_trove_admin
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT remote_neutron_client trove.common.single_tenant_remote.neutron_client_trove_admin
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT remote_swift_client trove.common.single_tenant_remote.swift_client_trove_admin
-    setup_trove_logging $TROVE_GUESTAGENT_CONF
 
-    # To avoid 'Connection timed out' error of sudo command inside the guest agent
-    CLOUDINIT_PATH=/etc/trove/cloudinit/${TROVE_DATASTORE_TYPE}.cloudinit
-    sudo mkdir -p $(dirname "$CLOUDINIT_PATH")
-    sudo touch "$CLOUDINIT_PATH"
-    sudo tee $CLOUDINIT_PATH >/dev/null <<'EOF'
+    iniset $TROVE_GUESTAGENT_CONF service_credentials username trove
+    iniset $TROVE_GUESTAGENT_CONF service_credentials user_domain_name Default
+    iniset $TROVE_GUESTAGENT_CONF service_credentials project_domain_name Default
+    iniset $TROVE_GUESTAGENT_CONF service_credentials password $SERVICE_PASSWORD
+    iniset $TROVE_GUESTAGENT_CONF service_credentials project_name $SERVICE_PROJECT_NAME
+    iniset $TROVE_GUESTAGENT_CONF service_credentials region_name $REGION_NAME
+    iniset $TROVE_GUESTAGENT_CONF service_credentials auth_url $TROVE_AUTH_ENDPOINT
+
+    # 1. To avoid 'Connection timed out' error of sudo command inside the guest agent
+    # 2. Config the controller IP address used by guest-agent to download Trove code during initialization (only valid for dev_mode=true).
+    common_cloudinit=/etc/trove/cloudinit/common.cloudinit
+    sudo mkdir -p $(dirname ${common_cloudinit})
+    sudo touch ${common_cloudinit}
+    sudo tee ${common_cloudinit} >/dev/null <<EOF
 #cloud-config
 manage_etc_hosts: "localhost"
+write_files:
+  - path: /etc/trove/controller.conf
+    content: |
+      CONTROLLER=${SERVICE_HOST}
 EOF
+
+    # NOTE(lxkong): Remove this when we support common cloud-init file for all datastores.
+    for datastore in "mysql" "mariadb" "postgresql"
+    do
+        sudo cp ${common_cloudinit} /etc/trove/cloudinit/${datastore}.cloudinit
+    done
 }
 
 # install_trove() - Collect source and prepare
@@ -311,6 +308,9 @@ function install_trove {
     if is_service_enabled horizon; then
         install_trove_dashboard
     fi
+
+    # Fix iptables rules that prevent amqp connections from the devstack box to the guests
+    sudo iptables -D openstack-INPUT -j REJECT --reject-with icmp-host-prohibited || true
 }
 
 # install_trove_dashboard() - Collect source and prepare
@@ -390,9 +390,11 @@ function setup_mgmt_network() {
     die_if_not_set $LINENO network_id "Failed to create network: $NET_NAME, project: ${PROJECT_ID}"
 
     if [[ "$IP_VERSION" =~ 4.* ]]; then
-        NEW_SUBNET_ID=$(create_mgmt_subnet_v4 ${PROJECT_ID} ${network_id} ${SUBNET_NAME} ${SUBNET_RANGE})
-        openstack router add subnet $ROUTER_ID $NEW_SUBNET_ID
+        net_subnet_id=$(create_mgmt_subnet_v4 ${PROJECT_ID} ${network_id} ${SUBNET_NAME} ${SUBNET_RANGE})
+        # 'openstack router add' has a bug that cound't show the error message
+        # openstack router add subnet ${ROUTER_ID} ${net_subnet_id} --debug
     fi
+
     # Trove doesn't support IPv6 for now.
 #    if [[ "$IP_VERSION" =~ .*6 ]]; then
 #        NEW_IPV6_SUBNET_ID=$(create_subnet_v6 ${PROJECT_ID} ${network_id} ${IPV6_SUBNET_NAME})
@@ -439,56 +441,54 @@ function configure_tempest_for_trove {
 
 # Use trovestack to create guest image and register the image in the datastore.
 function create_guest_image {
-    TROVE_DISABLE_IMAGE_SETUP=`echo ${TROVE_DISABLE_IMAGE_SETUP,,}`
-    if [[ ${TROVE_DISABLE_IMAGE_SETUP} == "true" ]]; then
+    TROVE_ENABLE_IMAGE_BUILD=`echo ${TROVE_ENABLE_IMAGE_BUILD,,}`
+    if [[ ${TROVE_ENABLE_IMAGE_BUILD} == "false" ]]; then
         echo "Skip creating guest image."
         return 0
     fi
 
-    echo "Starting to create guest image..."
-
-    $DEST/trove/integration/scripts/trovestack build-image ${TROVE_DATASTORE_TYPE} ${TROVE_IMAGE_OS} ${TROVE_IMAGE_OS_RELEASE} true
-
-    image_name="trove-${TROVE_IMAGE_OS}-${TROVE_IMAGE_OS_RELEASE}-${TROVE_DATASTORE_TYPE}"
+    image_name="trove-datastore-${TROVE_IMAGE_OS}-${TROVE_IMAGE_OS_RELEASE}-${TROVE_DATASTORE_TYPE}"
+    image_url_var="TROVE_NON_DEV_IMAGE_URL_${TROVE_DATASTORE_TYPE^^}"
+    image_url=`eval echo '$'"$image_url_var"`
+    mkdir -p $HOME/images
     image_file=$HOME/images/${image_name}.qcow2
-    if [ ! -f ${image_file} ]; then
-        echo "Image file was not found at ${image_file}. Probably it was not created."
-        return 1
+
+    if [[ -n ${image_url} ]]; then
+        echo "Downloading guest image from ${image_url}"
+        curl -sSL ${image_url} -o ${image_file}
+    else
+        echo "Starting to create guest image"
+
+        TROVE_BRANCH=${TROVE_BRANCH} $DEST/trove/integration/scripts/trovestack \
+          build-image \
+          ${TROVE_DATASTORE_TYPE} \
+          ${TROVE_IMAGE_OS} \
+          ${TROVE_IMAGE_OS_RELEASE} \
+          true
     fi
 
-    ACTIVE=1
-    INACTIVE=0
+    if [ ! -f ${image_file} ]; then
+        echo "Image file was not found at ${image_file}"
+        exit 1
+    fi
 
     echo "Add the image to glance"
     glance_image_id=$(openstack --os-region-name RegionOne --os-password ${SERVICE_PASSWORD} \
       --os-project-name service --os-username trove \
-      image create ${TROVE_IMAGE_OS}-${TROVE_IMAGE_OS_RELEASE}-${TROVE_DATASTORE_TYPE} \
+      image create ${image_name} \
       --disk-format qcow2 --container-format bare --property hw_rng_model='virtio' --file ${image_file} \
       -c id -f value)
 
     echo "Register the image in datastore"
     $TROVE_MANAGE datastore_update $TROVE_DATASTORE_TYPE ""
-    $TROVE_MANAGE datastore_version_update $TROVE_DATASTORE_TYPE $TROVE_DATASTORE_VERSION $TROVE_DATASTORE_TYPE $glance_image_id "" $ACTIVE
+    $TROVE_MANAGE datastore_version_update $TROVE_DATASTORE_TYPE $TROVE_DATASTORE_VERSION $TROVE_DATASTORE_TYPE $glance_image_id "" 1
     $TROVE_MANAGE datastore_update $TROVE_DATASTORE_TYPE $TROVE_DATASTORE_VERSION
 
-    # just for tests
-    $TROVE_MANAGE datastore_version_update "$TROVE_DATASTORE_TYPE" "inactive_version" "manager1" $glance_image_id "" $INACTIVE
-    $TROVE_MANAGE datastore_update Test_Datastore_1 ""
-
-    echo "Add validation rules if available"
+    echo "Add parameter validation rules if available"
     if [ -f $DEST/trove/trove/templates/$TROVE_DATASTORE_TYPE/validation-rules.json ]; then
         $TROVE_MANAGE db_load_datastore_config_parameters "$TROVE_DATASTORE_TYPE" "$TROVE_DATASTORE_VERSION" \
             $DEST/trove/trove/templates/$TROVE_DATASTORE_TYPE/validation-rules.json
     fi
-
-    # To avoid 'Connection timed out' error of sudo command inside the guest agent.
-    CLOUDINIT_PATH=/etc/trove/cloudinit/${TROVE_DATASTORE_TYPE}.cloudinit
-    sudo mkdir -p $(dirname "$CLOUDINIT_PATH")
-    sudo touch "$CLOUDINIT_PATH"
-    sudo tee $CLOUDINIT_PATH >/dev/null <<'EOF'
-#cloud-config
-manage_etc_hosts: "localhost"
-EOF
 }
 
 # Set up Trove management network and make configuration change.
@@ -550,11 +550,13 @@ function config_trove_network {
     openstack network list
     echo "Neutron subnet list:"
     openstack subnet list
+    echo "Neutron router:"
+    openstack router show ${ROUTER_ID} -f yaml
     echo "ip route:"
     sudo ip route
 
     # Now make sure the conf settings are right
-    iniset $TROVE_CONF DEFAULT network_label_regex ${PRIVATE_NETWORK_NAME}
+    iniset $TROVE_CONF DEFAULT network_label_regex ""
     iniset $TROVE_CONF DEFAULT ip_regex ""
     iniset $TROVE_CONF DEFAULT black_list_regex ""
     iniset $TROVE_CONF DEFAULT management_networks ${mgmt_net_id}
