@@ -14,6 +14,7 @@
 #    under the License.
 
 from oslo_log import log as logging
+from oslo_utils import strutils
 
 from trove.backup.models import Backup
 from trove.backup import views
@@ -39,9 +40,21 @@ class BackupController(wsgi.Controller):
         """
         LOG.debug("Listing backups for tenant %s", tenant_id)
         datastore = req.GET.get('datastore')
+        instance_id = req.GET.get('instance_id')
+        all_projects = strutils.bool_from_string(req.GET.get('all_projects'))
         context = req.environ[wsgi.CONTEXT_KEY]
-        policy.authorize_on_tenant(context, 'backup:index')
-        backups, marker = Backup.list(context, datastore)
+
+        if all_projects:
+            policy.authorize_on_tenant(context, 'backup:index:all_projects')
+        else:
+            policy.authorize_on_tenant(context, 'backup:index')
+
+        backups, marker = Backup.list(
+            context,
+            datastore=datastore,
+            instance_id=instance_id,
+            all_projects=all_projects
+        )
         view = views.BackupViews(backups)
         paged = pagination.SimplePaginatedDataView(req.url, 'backups', view,
                                                    marker)
