@@ -66,6 +66,12 @@ class NotFound(TroveError):
     message = _("Resource %(uuid)s cannot be found.")
 
 
+class BadRequest(TroveError):
+
+    message = _("The server could not comply with the request since it is "
+                "either malformed or otherwise incorrect.")
+
+
 class CapabilityNotFound(NotFound):
 
     message = _("Capability '%(capability)s' cannot be found.")
@@ -172,6 +178,21 @@ class DatastoreVersionInactive(TroveError):
     message = _("Datastore version '%(version)s' is not active.")
 
 
+class DatastoreVersionAlreadyExists(BadRequest):
+
+    message = _("A datastore version with the name '%(name)s' already exists.")
+
+
+class DatastoreVersionsExist(BadRequest):
+
+    message = _("Datastore versions exist for datastore %(datastore)s.")
+
+
+class DatastoreVersionsInUse(BadRequest):
+
+    message = _("Datastore version is in use by %(resource)s.")
+
+
 class DatastoreDefaultDatastoreNotFound(TroveError):
 
     message = _("Please specify datastore. Default datastore "
@@ -240,12 +261,6 @@ class GuestTimeout(TroveError):
     message = _("Timeout trying to connect to the Guest Agent.")
 
 
-class BadRequest(TroveError):
-
-    message = _("The server could not comply with the request since it is "
-                "either malformed or otherwise incorrect.")
-
-
 class MissingKey(BadRequest):
 
     message = _("Required element/key - %(key)s was not specified.")
@@ -596,6 +611,10 @@ class PublicNetworkNotFound(TroveError):
     message = _("Public network cannot be found.")
 
 
+class NetworkConflict(BadRequest):
+    message = _("User network conflicts with the management network.")
+
+
 class ClusterVolumeSizeRequired(TroveError):
     message = _("A volume size is required for each instance in the cluster.")
 
@@ -661,11 +680,6 @@ class ImageNotFound(NotFound):
     message = _("Image %(uuid)s cannot be found.")
 
 
-class DatastoreVersionAlreadyExists(BadRequest):
-
-    message = _("A datastore version with the name '%(name)s' already exists.")
-
-
 class LogAccessForbidden(Forbidden):
 
     message = _("You must be admin to %(action)s log '%(log)s'.")
