@@ -170,11 +170,15 @@ class TroveCommonTraits(TroveBaseTraits):
             if 'instance_type' not in self.payload:
                 flavor = instance.nova_client.flavors.get(instance.flavor_id)
                 self.payload['instance_size'] = flavor.ram
-            if self.server is None:
-                self.server = instance.nova_client.servers.get(
-                    instance.server_id)
-            self.payload['availability_zone'] = getattr(
-                self.server, 'OS-EXT-AZ:availability_zone', None)
+            if self.server is None and instance.server_id:
+                try:
+                    self.server = instance.nova_client.servers.get(
+                        instance.server_id)
+                except Exception:
+                    pass
+            if self.server:
+                self.payload['availability_zone'] = getattr(
+                    self.server, 'OS-EXT-AZ:availability_zone', None)
             if CONF.get(instance.datastore_version.manager).volume_support:
                 self.payload.update({
                     'volume_size': instance.volume_size,
@@ -364,7 +368,7 @@ class DBaaSAPINotification(object):
                                 'server_type': 'api',
                                 'client_ip': request.remote_addr,
                                 'server_ip': request.host,
-                                'tenant_id': context.tenant,
+                                'tenant_id': context.project_id,
                                 })
         elif 'request_id' not in kwargs:
             raise TroveError(_("Notification %s must include 'request'"
@@ -447,6 +451,15 @@ class DBaaSInstanceCreate(DBaaSAPINotification):
         return ['instance_id']
 
 
+class DBaaSInstanceReboot(DBaaSAPINotification):
+
+    def event_type(self):
+        return 'instance_reboot'
+
+    def required_start_traits(self):
+        return ['instance_id']
+
+
 class DBaaSInstanceRestart(DBaaSAPINotification):
 
     def event_type(self):
@@ -649,6 +662,10 @@ class DBaaSClusterGrow(DBaaSAPINotification):
     def required_start_traits(self):
         return ['cluster_id']
 
+    @abc.abstractmethod
+    def required_end_traits(self):
+        return ['cluster_id']
+
 
 class DBaaSClusterShrink(DBaaSAPINotification):
 
@@ -660,6 +677,10 @@ class DBaaSClusterShrink(DBaaSAPINotification):
     def required_start_traits(self):
         return ['cluster_id']
 
+    @abc.abstractmethod
+    def required_end_traits(self):
+        return ['cluster_id']
+
 
 class DBaaSBackupCreate(DBaaSAPINotification):
 
