@@ -14,14 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import jinja2
 from oslo_config import cfg as oslo_config
 from oslo_log import log as logging
 
 from trove.common import cfg
 from trove.common import configurations
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import utils
 
 CONF = cfg.CONF
@@ -33,10 +31,13 @@ SERVICE_PARSERS = {
     'mongodb': configurations.MongoDBConfParser,
     'mysql': configurations.MySQLConfParser,
     'percona': configurations.MySQLConfParser,
+    'mariadb': configurations.MySQLConfParser,
+    'pxc': configurations.MySQLConfParser,
     'postgresql': configurations.PostgresqlConfParser,
     'cassandra': configurations.CassandraConfParser,
     'redis': configurations.RedisConfParser,
     'vertica': configurations.VerticaConfParser,
+    'db2': configurations.DB2ConfParser,
 }
 
 
@@ -115,10 +116,6 @@ class SingleInstanceConfigTemplate(object):
         return abs(hash(self.instance_id) % (2 ** 31))
 
 
-class OverrideConfigTemplate(SingleInstanceConfigTemplate):
-    template_name = "override.config.template"
-
-
 def _validate_datastore(datastore_manager):
     try:
         CONF.get(datastore_manager)
@@ -127,20 +124,6 @@ def _validate_datastore(datastore_manager):
             datastore_manager=datastore_manager)
 
 
-def load_heat_template(datastore_manager):
-    patterns = ["%s/heat.template" % datastore_manager,
-                "default.heat.template"]
-    _validate_datastore(datastore_manager)
-    try:
-        template_obj = ENV.select_template(patterns)
-        return template_obj
-    except jinja2.TemplateNotFound:
-        msg = _("Missing heat template for %(s_datastore_manager)s.") % (
-            {"s_datastore_manager": datastore_manager})
-        LOG.error(msg)
-        raise exception.TroveError(msg)
-
-
 class ReplicaSourceConfigTemplate(SingleInstanceConfigTemplate):
     template_name = "replica_source.config.template"
 
