@@ -105,10 +105,8 @@ class DefaultRootController(BaseDatastoreRootController):
         LOG.info("Enabling root for instance '%s'.", instance_id)
         LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
-        user_name = context.user
         password = DefaultRootController._get_password_from_body(body)
-        root = models.Root.create(context, instance_id,
-                                  user_name, password)
+        root = models.Root.create(context, instance_id, password)
         return wsgi.Result(views.RootCreatedView(root).data(), 200)
 
     def root_delete(self, req, tenant_id, instance_id, is_cluster):
@@ -118,14 +116,11 @@ class DefaultRootController(BaseDatastoreRootController):
         LOG.info("Disabling root for instance '%s'.", instance_id)
         LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
-        try:
-            found_user = self._find_root_user(context, instance_id)
-        except (ValueError, AttributeError) as e:
-            raise exception.BadRequest(message=str(e))
-        if not found_user:
-            raise exception.UserNotFound(uuid="root")
+        is_root_enabled = models.Root.load(context, instance_id)
+        if not is_root_enabled:
+            raise exception.RootHistoryNotFound()
         models.Root.delete(context, instance_id)
-        return wsgi.Result(None, 200)
+        return wsgi.Result(None, 204)
 
 
 class ClusterRootController(DefaultRootController):
@@ -175,9 +170,8 @@ class ClusterRootController(DefaultRootController):
         LOG.info("Enabling root for instance '%s'.", instance_id)
         LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
-        user_name = context.user
         password = ClusterRootController._get_password_from_body(body)
-        root = models.ClusterRoot.create(context, instance_id, user_name,
+        root = models.ClusterRoot.create(context, instance_id,
                                          password, cluster_instances)
         return wsgi.Result(views.RootCreatedView(root).data(), 200)
 
@@ -241,7 +235,8 @@ class RootController(ExtensionController):
             return root_controller.root_delete(req, tenant_id,
                                                instance_id, is_cluster)
         else:
-            raise NoSuchOptError
+            opt = 'root_controller'
+            raise NoSuchOptError(opt, group='datastore_manager')
 
     def _get_datastore(self, tenant_id, instance_or_cluster_id):
         """
