@@ -16,6 +16,7 @@
 import inspect
 import operator
 import os
+import pwd
 import re
 import stat
 import tempfile
@@ -102,6 +103,26 @@ def exists(path, is_directory=False, as_root=False):
     return found
 
 
+def find_executable(executable, path=None):
+    """Finds a location of an executable in the locations listed in 'path'
+
+    :param executable          File to search.
+    :type executable           string
+
+    :param path                Lookup directories separated by a path
+                               separartor.
+    :type path                 string
+    """
+    if path is None:
+        path = os.environ.get('PATH', os.defpath)
+    dirs = path.split(os.pathsep)
+    for directory in dirs:
+        exec_path = os.path.join(directory, executable)
+        if os.path.isfile(exec_path) and os.access(exec_path, os.X_OK):
+            return exec_path
+    return None
+
+
 def _read_file_as_root(path, open_flag, convert_func):
     """Read a file as root.
 
@@ -841,3 +862,8 @@ def is_mount(path):
     directory_dev = get_device(path, as_root=True)
     parent_dev = get_device(os.path.join(path, '..'), as_root=True)
     return directory_dev != parent_dev
+
+
+def get_current_user():
+    """Returns name of the current OS user"""
+    return pwd.getpwuid(os.getuid())[0]
