@@ -28,12 +28,10 @@ REDIS_CONF_DIR = '/etc/redis'
 REDIS_DATA_DIR = '/var/lib/redis'
 REDIS_PORT = '6379'
 REDIS_INIT = '/etc/init/redis-server.conf'
-REDIS_CLI = '/usr/bin/redis-cli'
-REDIS_BIN = '/usr/bin/redis-server'
-REDIS_PACKAGE = 'redis-server'
+REDIS_PACKAGE = ''
 SERVICE_CANDIDATES = ['redis-server', 'redis']
 
 OS = get_os()
-if OS is 'redhat':
+if OS == 'redhat':
     REDIS_CONFIG = '/etc/redis.conf'
     REDIS_PACKAGE = 'redis'
