@@ -111,8 +111,8 @@ class Manager(periodic_task.PeriodicTasks):
         try:
             return repl_strategy.get_instance(self.manager)
         except Exception as ex:
-            LOG.debug("Cannot get replication instance for '%(manager)s': "
-                      "%(msg)s", {'manager': self.manager, 'msg': str(ex)})
+            LOG.warning("Cannot get replication instance for '%(manager)s': "
+                        "%(msg)s", {'manager': self.manager, 'msg': str(ex)})
 
         return None
 
@@ -142,8 +142,7 @@ class Manager(periodic_task.PeriodicTasks):
         """
         return None
 
-    @property
-    def datastore_log_defs(self):
+    def get_datastore_log_defs(self):
         """Any datastore-specific log files should be overridden in this dict
         by the corresponding Manager class.
 
@@ -182,11 +181,10 @@ class Manager(periodic_task.PeriodicTasks):
             },
         }
 
-    @property
-    def guest_log_defs(self):
+    def get_guest_log_defs(self):
         """Return all the guest log defs."""
         if not self._guest_log_defs:
-            self._guest_log_defs = dict(self.datastore_log_defs)
+            self._guest_log_defs = dict(self.get_datastore_log_defs())
             self._guest_log_defs.update(self.guestagent_log_defs)
         return self._guest_log_defs
 
@@ -198,8 +196,7 @@ class Manager(periodic_task.PeriodicTasks):
     def guest_log_context(self, context):
         self._guest_log_context = context
 
-    @property
-    def guest_log_cache(self):
+    def get_guest_log_cache(self):
         """Make sure the guest_log_cache is loaded and return it."""
         self._refresh_guest_log_cache()
         return self._guest_log_cache
@@ -215,7 +212,7 @@ class Manager(periodic_task.PeriodicTasks):
             # Load the initial cache
             self._guest_log_cache = {}
             if self.guest_log_context:
-                gl_defs = self.guest_log_defs
+                gl_defs = self.get_guest_log_defs()
                 try:
                     exposed_logs = CONF.get(self.manager).get(
                         'guest_log_exposed_logs')
@@ -241,16 +238,21 @@ class Manager(periodic_task.PeriodicTasks):
 
         self._guest_log_loaded_context = self.guest_log_context
 
-    ################
-    # Status related
-    ################
+    def get_service_status(self):
+        return self.status._get_actual_db_status()
+
     @periodic_task.periodic_task
     def update_status(self, context):
-        """Update the status of the trove instance. It is decorated with
-        perodic_task so it is called automatically.
-        """
-        LOG.debug("Update status called.")
-        self.status.update()
+        """Update the status of the trove instance."""
+        if not self.status.is_installed or self.status._is_restarting:
+            LOG.info("Database service is not installed or is in restart "
+                     "mode, skip status check")
+            return
+
+        LOG.debug("Starting to check database service status")
+
+        status = self.get_service_status()
+        self.status.set_status(status)
 
     def rpc_ping(self, context):
         LOG.debug("Responding to RPC ping.")
@@ -315,6 +317,7 @@ class Manager(periodic_task.PeriodicTasks):
         except Exception as ex:
             LOG.exception("An error occurred applying modules: "
                           "%s", str(ex))
+
         # The following block performs single-instance initialization.
         # Failures will be recorded, but won't stop the provisioning
         # or change the instance state.
@@ -490,7 +493,7 @@ class Manager(periodic_task.PeriodicTasks):
     def guest_log_list(self, context):
         LOG.info("Getting list of guest logs.")
         self.guest_log_context = context
-        gl_cache = self.guest_log_cache
+        gl_cache = self.get_guest_log_cache()
         result = filter(None, [gl_cache[log_name].show()
                                if gl_cache[log_name].exposed else None
                                for log_name in gl_cache.keys()])
@@ -511,7 +514,7 @@ class Manager(periodic_task.PeriodicTasks):
                  {'log': log_name, 'en': enable, 'dis': disable,
                   'pub': publish, 'disc': discard})
         self.guest_log_context = context
-        gl_cache = self.guest_log_cache
+        gl_cache = self.get_guest_log_cache()
         if log_name in gl_cache:
             if ((gl_cache[log_name].type == guest_log.LogType.SYS) and
                     not publish):
@@ -557,7 +560,7 @@ class Manager(periodic_task.PeriodicTasks):
         if self.configuration_manager:
             LOG.debug("%(verb)s log '%(log)s'", {'verb': verb,
                                                  'log': log_name})
-            gl_def = self.guest_log_defs[log_name]
+            gl_def = self.get_guest_log_defs()[log_name]
             enable_cfg_label = "%s_%s_log" % (self.GUEST_LOG_ENABLE_LABEL,
                                               log_name)
             disable_cfg_label = "%s_%s_log" % (self.GUEST_LOG_DISABLE_LABEL,
@@ -608,7 +611,7 @@ class Manager(periodic_task.PeriodicTasks):
         """Sets the status of log_name to 'status' - if log_name is not
         provided, sets the status on all logs.
         """
-        gl_cache = self.guest_log_cache
+        gl_cache = self.get_guest_log_cache()
         names = [log_name]
         if not log_name or log_name not in gl_cache:
             names = gl_cache.keys()
