@@ -50,7 +50,8 @@ from trove.guestagent.datastore import service
 from trove.guestagent import pkg
 
 ADMIN_USER_NAME = "os_admin"
-CONNECTION_STR_FORMAT = "mysql+pymysql://%s:%s@127.0.0.1:3306"
+CONNECTION_STR_FORMAT = ("mysql+pymysql://%s:%s@localhost/?"
+                         "unix_socket=/var/run/mysqld/mysqld.sock")
 LOG = logging.getLogger(__name__)
 FLUSH = text(sql_query.FLUSH)
 ENGINE = None
@@ -95,20 +96,28 @@ def clear_expired_password():
         out, err = utils.execute("cat", secret_file,
                                  run_as_root=True, root_helper="sudo")
     except exception.ProcessExecutionError:
-        LOG.exception("/root/.mysql_secret does not exist.")
-        return
-    m = re.match('# The random password set for the root user at .*: (.*)',
-                 out)
-    if m:
-        try:
-            out, err = utils.execute("mysqladmin", "-p%s" % m.group(1),
-                                     "password", "", run_as_root=True,
-                                     root_helper="sudo")
-        except exception.ProcessExecutionError:
-            LOG.exception("Cannot change mysql password.")
-            return
-        operating_system.remove(secret_file, force=True, as_root=True)
-        LOG.debug("Expired password removed.")
+        LOG.warning("/root/.mysql_secret does not exist.")
+    else:
+        m = re.match('# The random password set for the root user at .*: (.*)',
+                     out)
+        if m:
+            try:
+                out, err = utils.execute("mysqladmin", "-p%s" % m.group(1),
+                                         "password", "", run_as_root=True,
+                                         root_helper="sudo")
+            except exception.ProcessExecutionError:
+                LOG.exception("Cannot change mysql password.")
+                return
+            operating_system.remove(secret_file, force=True, as_root=True)
+            LOG.debug("Expired password removed.")
+
+    # The root user password will be changed in app.secure_root() later on
+    LOG.debug('Initializae the root password to empty')
+    try:
+        utils.execute("mysqladmin", "--user=root", "password", "",
+                      run_as_root=True, root_helper="sudo")
+    except Exception:
+        LOG.exception("Failed to initializae the root password")
 
 
 def load_mysqld_options():
@@ -144,35 +153,34 @@ class BaseMySqlAppStatus(service.BaseDbStatus):
         return cls._instance
 
     def _get_actual_db_status(self):
+        """Check database service status.
+
+        The checks which don't need service app can be put here.
+        """
         try:
-            out, err = utils.execute_with_timeout(
-                "/usr/bin/mysqladmin",
-                "ping", run_as_root=True, root_helper="sudo",
-                log_output_on_error=True)
-            LOG.info("MySQL Service Status is RUNNING.")
+            out, _ = utils.execute_with_timeout(
+                "/bin/ps", "-C", "mysqld", "h",
+                log_output_on_error=True
+            )
+            pid = out.split()[0]
+
+            LOG.debug('Database service check: service PID exists: %s', pid)
             return rd_instance.ServiceStatuses.RUNNING
         except exception.ProcessExecutionError:
-            LOG.exception("Failed to get database status.")
-            try:
-                out, err = utils.execute_with_timeout("/bin/ps", "-C",
-                                                      "mysqld", "h")
-                pid = out.split()[0]
-                # TODO(rnirmal): Need to create new statuses for instances
-                # where the mysql service is up, but unresponsive
-                LOG.info('MySQL Service Status %(pid)s is BLOCKED.',
-                         {'pid': pid})
-                return rd_instance.ServiceStatuses.BLOCKED
-            except exception.ProcessExecutionError:
-                LOG.exception("Process execution failed.")
-                mysql_args = load_mysqld_options()
-                pid_file = mysql_args.get('pid_file',
-                                          ['/var/run/mysqld/mysqld.pid'])[0]
-                if os.path.exists(pid_file):
-                    LOG.info("MySQL Service Status is CRASHED.")
-                    return rd_instance.ServiceStatuses.CRASHED
-                else:
-                    LOG.info("MySQL Service Status is SHUTDOWN.")
-                    return rd_instance.ServiceStatuses.SHUTDOWN
+            LOG.warning("Database service check: Failed to get database "
+                        "service status by ps, fall back to check PID file.")
+
+        mysql_args = load_mysqld_options()
+        pid_file = mysql_args.get('pid_file',
+                                  ['/var/run/mysqld/mysqld.pid'])[0]
+        if os.path.exists(pid_file):
+            LOG.info("Database service check: MySQL Service Status is "
+                     "CRASHED.")
+            return rd_instance.ServiceStatuses.CRASHED
+        else:
+            LOG.info("Database service check: MySQL Service Status is "
+                     "SHUTDOWN.")
+            return rd_instance.ServiceStatuses.SHUTDOWN
 
 
 class BaseLocalSqlClient(object):
@@ -298,6 +306,7 @@ class BaseMySqlAdmin(object):
                                               mydb.character_set,
                                               mydb.collate)
                 t = text(str(cd))
+                LOG.debug('Creating database, command: %s', str(cd))
                 client.execute(t)
 
     def create_user(self, users):
@@ -308,18 +317,18 @@ class BaseMySqlAdmin(object):
             for item in users:
                 user = models.MySQLUser.deserialize(item)
                 user.check_create()
-                # TODO(cp16net):Should users be allowed to create users
-                # 'os_admin' or 'debian-sys-maint'
-                g = sql_query.Grant(user=user.name, host=user.host,
-                                    clear=user.password)
-                t = text(str(g))
-                client.execute(t)
+
+                cu = sql_query.CreateUser(user.name, host=user.host,
+                                          clear=user.password)
+                t = text(str(cu))
+                client.execute(t, **cu.keyArgs)
+
                 for database in user.databases:
                     mydb = models.MySQLSchema.deserialize(database)
                     g = sql_query.Grant(permissions='ALL', database=mydb.name,
-                                        user=user.name, host=user.host,
-                                        clear=user.password)
+                                        user=user.name, host=user.host)
                     t = text(str(g))
+                    LOG.debug('Creating user, command: %s', str(g))
                     client.execute(t)
 
     def delete_database(self, database):
@@ -570,11 +579,12 @@ class BaseKeepAliveConnection(interfaces.PoolListener):
             else:
                 raise
         # MariaDB seems to timeout the client in a different
-        # way than MySQL and PXC, which manifests itself as
-        # an invalid packet sequence.  Handle it as well.
+        # way than MySQL and PXC
         except pymysql_err.InternalError as ex:
             if "Packet sequence number wrong" in str(ex):
                 raise exc.DisconnectionError()
+            elif 'Connection was killed' in str(ex):
+                raise exc.DisconnectionError()
             else:
                 raise
 
@@ -608,20 +618,28 @@ class BaseMySqlApp(object):
         override_strategy=ImportOverrideStrategy(CNF_INCLUDE_DIR, CNF_EXT))
 
     def get_engine(self):
-        """Create the default engine with the updated admin user."""
-        # TODO(rnirmal):Based on permission issues being resolved we may revert
-        # url = URL(drivername='mysql', host='localhost',
-        #          query={'read_default_file': '/etc/mysql/my.cnf'})
+        """Create the default engine with the updated admin user.
+
+        If admin user not created yet, use root instead.
+        """
         global ENGINE
         if ENGINE:
             return ENGINE
 
-        pwd = self.get_auth_password()
+        user = ADMIN_USER_NAME
+        password = ""
+        try:
+            password = self.get_auth_password()
+        except exception.UnprocessableEntity:
+            # os_admin user not created yet
+            user = 'root'
+
         ENGINE = sqlalchemy.create_engine(
-            CONNECTION_STR_FORMAT % (ADMIN_USER_NAME,
-                                     urllib.parse.quote(pwd.strip())),
+            CONNECTION_STR_FORMAT % (user,
+                                     urllib.parse.quote(password.strip())),
             pool_recycle=120, echo=CONF.sql_query_logging,
             listeners=[self.keep_alive_connection_cls()])
+
         return ENGINE
 
     @classmethod
@@ -657,9 +675,23 @@ class BaseMySqlApp(object):
         with all privileges similar to the root user.
         """
         LOG.debug("Creating Trove admin user '%s'.", ADMIN_USER_NAME)
-        host = "127.0.0.1"
+        host = "localhost"
+        try:
+            cu = sql_query.CreateUser(ADMIN_USER_NAME, host=host,
+                                      clear=password)
+            t = text(str(cu))
+            client.execute(t, **cu.keyArgs)
+        except (exc.OperationalError, exc.InternalError) as err:
+            # Ignore, user is already created, just reset the password
+            # (user will already exist in a restore from backup)
+            LOG.debug(err)
+            uu = sql_query.SetPassword(ADMIN_USER_NAME, host=host,
+                                       new_password=password)
+            t = text(str(uu))
+            client.execute(t)
+
         g = sql_query.Grant(permissions='ALL', user=ADMIN_USER_NAME,
-                            host=host, grant_option=True, clear=password)
+                            host=host, grant_option=True)
         t = text(str(g))
         client.execute(t)
         LOG.debug("Trove admin user '%s' created.", ADMIN_USER_NAME)
@@ -704,8 +736,12 @@ class BaseMySqlApp(object):
     def secure(self, config_contents):
         LOG.debug("Securing MySQL now.")
         clear_expired_password()
+
         LOG.debug("Generating admin password.")
         admin_password = utils.generate_random_password()
+
+        # By default, MySQL does not require a password at all for connecting
+        # as root
         engine = sqlalchemy.create_engine(
             CONNECTION_STR_FORMAT % ('root', ''), echo=True)
         with self.local_sql_client(engine, use_flush=False) as client:
@@ -735,9 +771,11 @@ class BaseMySqlApp(object):
         self.wipe_ib_logfiles()
 
     def _save_authentication_properties(self, admin_password):
+        # Use localhost to connect with mysql using unix socket instead of ip
+        # and port.
         client_sect = {'client': {'user': ADMIN_USER_NAME,
                                   'password': admin_password,
-                                  'host': '127.0.0.1'}}
+                                  'host': 'localhost'}}
         operating_system.write_file(self.get_client_auth_file(),
                                     client_sect, codec=self.CFG_CODEC)
 
@@ -1087,8 +1125,7 @@ class BaseMySqlRootAccess(object):
             g = sql_query.Grant(permissions=CONF.root_grant,
                                 user=user.name,
                                 host=user.host,
-                                grant_option=CONF.root_grant_option,
-                                clear=user.password)
+                                grant_option=CONF.root_grant_option)
 
             t = text(str(g))
             client.execute(t)
