@@ -67,16 +67,18 @@ class InnoBackupEx(base.BackupRunner):
 
     @property
     def user_and_pass(self):
-        return (' --user=%(user)s --password=%(password)s --host=127.0.0.1 ' %
+        return ('--user=%(user)s --password=%(password)s --host=localhost '
+                '--socket=%(socket_file)s' %
                 {'user': ADMIN_USER_NAME,
-                 'password': MySqlApp.get_auth_password()})
+                 'password': MySqlApp.get_auth_password(),
+                 'socket_file': '/var/run/mysqld/mysqld.sock'})
 
     @property
     def cmd(self):
         cmd = ('sudo innobackupex'
                ' --stream=xbstream'
                ' %(extra_opts)s ' +
-               self.user_and_pass +
+               self.user_and_pass + ' ' +
                MySqlApp.get_data_dir() +
                ' 2>/tmp/innobackupex.log'
                )
@@ -100,7 +102,7 @@ class InnoBackupEx(base.BackupRunner):
         return True
 
     def metadata(self):
-        LOG.debug('Getting metadata from backup.')
+        LOG.debug('Getting metadata for backup %s', self.base_filename)
         meta = {}
         lsn = re.compile(r"The latest check point \(for incremental\): "
                          r"'(\d+)'")
@@ -109,7 +111,7 @@ class InnoBackupEx(base.BackupRunner):
             match = lsn.search(output)
             if match:
                 meta = {'lsn': match.group(1)}
-        LOG.info("Metadata for backup: %s.", str(meta))
+        LOG.info("Metadata for backup %s: %s", self.base_filename, meta)
         return meta
 
     @property
@@ -134,7 +136,7 @@ class InnoBackupExIncremental(InnoBackupEx):
                ' --incremental'
                ' --incremental-lsn=%(lsn)s'
                ' %(extra_opts)s ' +
-               self.user_and_pass +
+               self.user_and_pass + ' ' +
                MySqlApp.get_data_dir() +
                ' 2>/tmp/innobackupex.log')
         return cmd + self.zip_cmd + self.encrypt_cmd
