@@ -24,22 +24,23 @@ import six
 from novaclient import exceptions as nova_exceptions
 from oslo_config.cfg import NoSuchOptError
 from oslo_log import log as logging
+from oslo_utils import encodeutils
 from sqlalchemy import func
 
 from trove.backup.models import Backup
 from trove.common import cfg
+from trove.common.clients import create_cinder_client
+from trove.common.clients import create_dns_client
+from trove.common.clients import create_glance_client
+from trove.common.clients import create_guest_client
+from trove.common.clients import create_neutron_client
+from trove.common.clients import create_nova_client
 from trove.common import crypto_utils as cu
 from trove.common import exception
-from trove.common.glance_remote import create_glance_client
 from trove.common.i18n import _
 from trove.common import instance as tr_instance
 from trove.common import neutron
 from trove.common import notification
-from trove.common.remote import create_cinder_client
-from trove.common.remote import create_dns_client
-from trove.common.remote import create_guest_client
-from trove.common.remote import create_neutron_client
-from trove.common.remote import create_nova_client
 from trove.common import server_group as srv_grp
 from trove.common import template
 from trove.common import timeutils
@@ -96,6 +97,7 @@ def load_server(context, instance_id, server_id, region_name):
 
 
 class InstanceStatus(object):
+    HEALTHY = "HEALTHY"
     ACTIVE = "ACTIVE"
     BLOCKED = "BLOCKED"
     BUILD = "BUILD"
@@ -177,15 +179,17 @@ class SimpleInstance(object):
         self.root_pass = root_password
         self._fault = None
         self._fault_loaded = False
-        if ds_version is None:
+        self.ds_version = None
+        self.ds = None
+        self.locality = locality
+        self.slave_list = None
+
+        if ds_version is None and self.db_info.datastore_version_id:
             self.ds_version = (datastore_models.DatastoreVersion.
                                load_by_uuid(self.db_info.datastore_version_id))
-        if ds is None:
+        if ds is None and self.ds_version:
             self.ds = (datastore_models.Datastore.
                        load(self.ds_version.datastore_id))
-        self.locality = locality
-
-        self.slave_list = None
 
     def __repr__(self, *args, **kwargs):
         return "%s(%s)" % (self.name, self.id)
@@ -361,7 +365,8 @@ class SimpleInstance(object):
 
         # Report as Shutdown while deleting, unless there's an error.
         if 'DELETING' == action:
-            if self.db_info.server_status in ["ACTIVE", "SHUTDOWN", "DELETED"]:
+            if self.db_info.server_status in ["ACTIVE", "SHUTDOWN", "DELETED",
+                                              "HEALTHY"]:
                 return InstanceStatus.SHUTDOWN
             else:
                 LOG.error("While shutting down instance (%(instance)s): "
@@ -385,6 +390,10 @@ class SimpleInstance(object):
     def updated(self):
         return self.db_info.updated
 
+    @property
+    def service_status_updated(self):
+        return self.datastore_status.updated_at
+
     @property
     def volume_id(self):
         return self.db_info.volume_id
@@ -403,11 +412,15 @@ class SimpleInstance(object):
 
     @property
     def volume_support(self):
-        return CONF.get(self.datastore_version.manager).volume_support
+        if self.datastore_version:
+            return CONF.get(self.datastore_version.manager).volume_support
+        return None
 
     @property
     def device_path(self):
-        return CONF.get(self.datastore_version.manager).device_path
+        if self.datastore_version:
+            return CONF.get(self.datastore_version.manager).device_path
+        return None
 
     @property
     def root_password(self):
@@ -782,7 +795,9 @@ class BaseInstance(SimpleInstance):
         try:
             if self.volume_id:
                 volume = self.volume_client.volumes.get(self.volume_id)
-                if volume.status == "available":
+                if volume.status in ["available", "error"]:
+                    LOG.info("Deleting volume %s for instance %s",
+                             self.volume_id, self.id)
                     volume.delete()
         except Exception as e:
             LOG.warning("Failed to delete volume for instance %s, error: %s",
@@ -800,8 +815,13 @@ class BaseInstance(SimpleInstance):
         deleted_at = timeutils.utcnow()
         self._delete_resources(deleted_at)
         LOG.debug("Setting instance %s to be deleted.", self.id)
+        # Also set FOREIGN KEY fields to NULL
         self.update_db(deleted=True, deleted_at=deleted_at,
-                       task_status=InstanceTasks.NONE)
+                       task_status=InstanceTasks.NONE,
+                       datastore_version_id=None,
+                       configuration_id=None,
+                       slave_of_id=None,
+                       cluster_id=None)
         self.set_servicestatus_deleted()
         self.set_instance_fault_deleted()
 
@@ -858,8 +878,6 @@ class BaseInstance(SimpleInstance):
         return self._neutron_client
 
     def reset_task_status(self):
-        LOG.info("Resetting task status to NONE on instance %s.",
-                 self.id)
         self.update_db(task_status=InstanceTasks.NONE)
 
     @property
@@ -892,11 +910,10 @@ class BaseInstance(SimpleInstance):
 
         instance_key = get_instance_encryption_key(self.id)
         if instance_key:
-            files = {guest_info_file: (
-                "%s"
-                "instance_rpc_encr_key=%s\n" % (
-                    files.get(guest_info_file),
-                    instance_key))}
+            files = {
+                guest_info_file: ("%sinstance_rpc_encr_key=%s\n" %
+                                  (files.get(guest_info_file), instance_key))
+            }
 
         if os.path.isfile(CONF.get('guest_config')):
             with open(CONF.get('guest_config'), "r") as f:
@@ -958,7 +975,9 @@ class Instance(BuiltInstance):
                 raise exception.TroveError(
                     "Flavors differ between regions"
                     " %(local)s and %(remote)s." %
-                    {'local': CONF.os_region_name, 'remote': region_name})
+                    {'local': CONF.service_credentials.region_name,
+                     'remote': region_name}
+                )
         except nova_exceptions.NotFound:
             raise exception.TroveError(
                 "Flavors %(flavor)s not found in region %(remote)s."
@@ -973,7 +992,9 @@ class Instance(BuiltInstance):
                 raise exception.TroveError(
                     "Datastore versions differ between regions "
                     "%(local)s and %(remote)s." %
-                    {'local': CONF.os_region_name, 'remote': region_name})
+                    {'local': CONF.service_credentials.region_name,
+                     'remote': region_name}
+                )
         except exception.NotFound:
             raise exception.TroveError(
                 "Datastore Version %(dsv)s not found in region %(remote)s."
@@ -989,7 +1010,8 @@ class Instance(BuiltInstance):
             raise exception.TroveError(
                 "Images for Datastore %(ds)s do not match "
                 "between regions %(local)s and %(remote)s." %
-                {'ds': datastore.name, 'local': CONF.os_region_name,
+                {'ds': datastore.name,
+                 'local': CONF.service_credentials.region_name,
                  'remote': region_name})
 
     @classmethod
@@ -1000,7 +1022,7 @@ class Instance(BuiltInstance):
                replica_count=None, volume_type=None, modules=None,
                locality=None, region_name=None, access=None):
 
-        region_name = region_name or CONF.os_region_name
+        region_name = region_name or CONF.service_credentials.region_name
 
         call_args = {
             'name': name,
@@ -1036,7 +1058,7 @@ class Instance(BuiltInstance):
 
         # If a different region is specified for the instance, ensure
         # that the flavor and image are the same in both regions
-        if region_name and region_name != CONF.os_region_name:
+        if region_name and region_name != CONF.service_credentials.region_name:
             cls._validate_remote_datastore(context, region_name, flavor,
                                            datastore, datastore_version)
 
@@ -1412,7 +1434,7 @@ class Instance(BuiltInstance):
         """
         # cases where action cannot be performed
         status_type = 'instance'
-        if self.db_info.server_status != 'ACTIVE':
+        if self.db_info.server_status not in ['ACTIVE', 'HEALTHY']:
             status = self.db_info.server_status
         elif (self.db_info.task_status != InstanceTasks.NONE and
               self.db_info.task_status != InstanceTasks.RESTART_REQUIRED):
@@ -1695,8 +1717,8 @@ class Instances(object):
                     db.addresses = {}
                 else:
                     try:
-                        if (not db.region_id
-                                or db.region_id == CONF.os_region_name):
+                        region = CONF.service_credentials.region_name
+                        if (not db.region_id or db.region_id == region):
                             server = find_server(db.id, db.compute_instance_id)
                         else:
                             nova_client = create_nova_client(
@@ -1808,6 +1830,10 @@ class instance_encryption_key_cache(object):
             if val is None:
                 return val
 
+            # We need string anyway
+            if isinstance(val, six.binary_type):
+                val = encodeutils.safe_decode(val)
+
             if len(self._lru) == self._lru_cache_size:
                 tail = self._lru.pop()
                 del self._table[tail]
@@ -1982,4 +2008,7 @@ def persisted_models():
     }
 
 
-MYSQL_RESPONSIVE_STATUSES = [tr_instance.ServiceStatuses.RUNNING]
+MYSQL_RESPONSIVE_STATUSES = [
+    tr_instance.ServiceStatuses.RUNNING,
+    tr_instance.ServiceStatuses.HEALTHY
+]
