@@ -193,7 +193,7 @@ class API(object):
                         availability_zone=None, root_password=None,
                         nics=None, overrides=None, slave_of_id=None,
                         cluster_config=None, volume_type=None,
-                        modules=None, locality=None):
+                        modules=None, locality=None, access=None):
 
         LOG.debug("Making async call to create instance %s ", instance_id)
         version = self.API_BASE_VERSION
@@ -214,7 +214,7 @@ class API(object):
                    slave_of_id=slave_of_id,
                    cluster_config=cluster_config,
                    volume_type=volume_type,
-                   modules=modules, locality=locality)
+                   modules=modules, locality=locality, access=access)
 
     def create_cluster(self, cluster_id):
         LOG.debug("Making async call to create cluster %s ", cluster_id)
