@@ -19,13 +19,13 @@ from oslo_utils import importutils
 
 from trove.backup.models import Backup
 import trove.common.cfg as cfg
+from trove.common import clients
 from trove.common.context import TroveContext
 from trove.common import exception
 from trove.common.exception import ReplicationSlaveAttachError
 from trove.common.exception import TroveError
 from trove.common.i18n import _
 from trove.common.notification import DBaaSQuotas, EndNotification
-from trove.common import remote
 from trove.common import server_group as srv_grp
 from trove.common.strategies.cluster import strategy
 from trove.datastore.models import DatastoreVersion
@@ -44,9 +44,9 @@ class Manager(periodic_task.PeriodicTasks):
     def __init__(self):
         super(Manager, self).__init__(CONF)
         self.admin_context = TroveContext(
-            user=CONF.nova_proxy_admin_user,
-            tenant=CONF.nova_proxy_admin_tenant_id,
-            user_domain_name=CONF.nova_proxy_admin_user_domain_name)
+            user=CONF.service_credentials.username,
+            tenant=CONF.service_credentials.project_id,
+            user_domain_name=CONF.service_credentials.user_domain_name)
         if CONF.exists_notification_transformer:
             self.exists_transformer = importutils.import_object(
                 CONF.exists_notification_transformer,
@@ -330,8 +330,8 @@ class Manager(periodic_task.PeriodicTasks):
         master_instance_tasks = BuiltInstanceTasks.load(context, slave_of_id)
         server_group = master_instance_tasks.server_group
         scheduler_hints = srv_grp.ServerGroup.convert_to_hint(server_group)
-        LOG.info("Using scheduler hints %s for creating instance %s",
-                 scheduler_hints, instance_id)
+        LOG.debug("Using scheduler hints %s for creating instance %s",
+                  scheduler_hints, instance_id)
 
         try:
             for replica_index in range(0, len(ids)):
@@ -344,14 +344,17 @@ class Manager(periodic_task.PeriodicTasks):
                     snapshot = instance_tasks.get_replication_master_snapshot(
                         context, slave_of_id, flavor, replica_backup_id,
                         replica_number=replica_number)
+
                     replica_backup_id = snapshot['dataset']['snapshot_id']
                     replica_backup_created = (replica_backup_id is not None)
+
                     instance_tasks.create_instance(
                         flavor, image_id, databases, users, datastore_manager,
                         packages, volume_size, replica_backup_id,
                         availability_zone, root_passwords[replica_index],
                         nics, overrides, None, snapshot, volume_type,
                         modules, scheduler_hints)
+
                     replicas.append(instance_tasks)
                 except Exception:
                     # if it's the first replica, then we shouldn't continue
@@ -390,8 +393,8 @@ class Manager(periodic_task.PeriodicTasks):
             scheduler_hints = srv_grp.ServerGroup.build_scheduler_hint(
                 context, locality, instance_id
             )
-            LOG.info("Using scheduler hints %s for creating instance %s",
-                     scheduler_hints, instance_id)
+            LOG.debug("Using scheduler hints %s for creating instance %s",
+                      scheduler_hints, instance_id)
 
             instance_tasks = FreshInstanceTasks.load(context, instance_id)
             instance_tasks.create_instance(
@@ -482,7 +485,7 @@ class Manager(periodic_task.PeriodicTasks):
     if CONF.quota_notification_interval:
         @periodic_task.periodic_task(spacing=CONF.quota_notification_interval)
         def publish_quota_notifications(self, context):
-            nova_client = remote.create_nova_client(self.admin_context)
+            nova_client = clients.create_nova_client(self.admin_context)
             for tenant in nova_client.tenants.list():
                 for quota in QUOTAS.get_all_quotas_by_tenant(tenant.id):
                     usage = QUOTAS.get_quota_usage(quota)
