@@ -32,6 +32,10 @@ from trove.cluster.models import Cluster
 from trove.cluster.models import DBCluster
 from trove.cluster import tasks
 from trove.common import cfg
+from trove.common import clients
+from trove.common.clients import create_cinder_client
+from trove.common.clients import create_dns_client
+from trove.common.clients import create_guest_client
 from trove.common import crypto_utils as cu
 from trove.common import exception
 from trove.common.exception import BackupCreationError
@@ -53,10 +57,6 @@ from trove.common.notification import (
     TroveInstanceCreate,
     TroveInstanceModifyVolume,
     TroveInstanceModifyFlavor)
-import trove.common.remote as remote
-from trove.common.remote import create_cinder_client
-from trove.common.remote import create_dns_client
-from trove.common.remote import create_guest_client
 from trove.common.strategies.cluster import strategy
 from trove.common import template
 from trove.common import timeutils
@@ -424,6 +424,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         error_message = ''
         error_details = ''
         try:
+            LOG.info("Waiting for instance %s up and running with "
+                     "timeout %ss", self.id, timeout)
             utils.poll_until(self._service_is_active,
                              sleep_time=CONF.usage_sleep_time,
                              time_out=timeout)
@@ -431,20 +433,22 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             TroveInstanceCreate(instance=self,
                                 instance_size=flavor['ram']).notify()
         except (TroveError, PollTimeOut) as ex:
-            LOG.exception("Failed to create instance %s.", self.id)
+            LOG.error("Failed to create instance %s, error: %s.",
+                      self.id, str(ex))
             self.update_statuses_on_time_out()
             error_message = "%s" % ex
             error_details = traceback.format_exc()
         except Exception as ex:
-            LOG.exception("Failed to send usage create-event for "
-                          "instance %s.", self.id)
+            LOG.error("Failed to send usage create-event for instance %s, "
+                      "error: %s", self.id, str(ex))
             error_message = "%s" % ex
             error_details = traceback.format_exc()
         finally:
             if error_message:
                 inst_models.save_instance_fault(
                     self.id, error_message, error_details,
-                    skip_delta=CONF.usage_sleep_time + 1)
+                    skip_delta=CONF.usage_sleep_time + 1
+                )
 
     def _create_port(self, network, security_groups, is_mgmt=False,
                      is_public=False):
@@ -474,9 +478,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                                        access=None):
         """Prepare the networks for the trove instance.
 
-        the params are all passed from trove-taskmanager.
-
-        Exception is raised if any error happens.
+        'nics' contains the networks that management network always comes at
+        last.
         """
         LOG.info("Preparing networks for the instance %s", self.id)
         security_group = None
@@ -563,13 +566,13 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
         backup_info = None
         if backup_id is not None:
-                backup = bkup_models.Backup.get_by_id(self.context, backup_id)
-                backup_info = {'id': backup_id,
-                               'instance_id': backup.instance_id,
-                               'location': backup.location,
-                               'type': backup.backup_type,
-                               'checksum': backup.checksum,
-                               }
+            backup = bkup_models.Backup.get_by_id(self.context, backup_id)
+            backup_info = {'id': backup_id,
+                           'instance_id': backup.instance_id,
+                           'location': backup.location,
+                           'type': backup.backup_type,
+                           'checksum': backup.checksum,
+                           }
         self._guest_prepare(flavor['ram'], volume_info,
                             packages, databases, users, backup_info,
                             config.config_contents, root_password,
@@ -620,7 +623,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 if backup:
                     backup_id = backup.id
         else:
-            LOG.debug('Skipping replication backup, as none is required.')
+            LOG.debug('Will skip replication master backup')
+
         snapshot_info = {
             'name': "Replication snapshot for %s" % self.id,
             'description': "Backup image used to initialize "
@@ -759,11 +763,11 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         """
         service = InstanceServiceStatus.find_by(instance_id=self.id)
         status = service.get_status()
-        LOG.debug("Service status of instance %(instance)s is %(status)s",
-                  {"instance": self.id, "status": status})
+
         if (status == rd_instance.ServiceStatuses.RUNNING or
-           status == rd_instance.ServiceStatuses.INSTANCE_READY):
-                return True
+                status == rd_instance.ServiceStatuses.INSTANCE_READY or
+                status == rd_instance.ServiceStatuses.HEALTHY):
+            return True
         elif status not in [rd_instance.ServiceStatuses.NEW,
                             rd_instance.ServiceStatuses.BUILDING,
                             rd_instance.ServiceStatuses.UNKNOWN,
@@ -771,9 +775,16 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             raise TroveError(_("Service not active, status: %s") % status)
 
         c_id = self.db_info.compute_instance_id
-        server = self.nova_client.servers.get(c_id)
+        try:
+            server = self.nova_client.servers.get(c_id)
+        except Exception as e:
+            raise TroveError(
+                _("Failed to get server %(server)s for instance %(instance)s, "
+                  "error: %(error)s"),
+                server=c_id, instance=self.id, error=str(e)
+            )
+
         server_status = server.status
-        LOG.debug("Server status of instance %s is %s", self.id, server_status)
         if server_status in [InstanceStatus.ERROR,
                              InstanceStatus.FAILED]:
             server_fault_message = 'No fault found'
@@ -1089,11 +1100,12 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
         action.execute()
 
     def create_backup(self, backup_info):
-        LOG.info("Initiating backup for instance %s.", self.id)
+        LOG.info("Initiating backup for instance %s, backup_info: %s", self.id,
+                 backup_info)
         self.guest.create_backup(backup_info)
 
     def backup_required_for_replication(self):
-        LOG.debug("Seeing if replication backup is required for instance %s.",
+        LOG.debug("Check if replication backup is required for instance %s.",
                   self.id)
         return self.guest.backup_required_for_replication()
 
@@ -1105,7 +1117,9 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 rep_source_config = self._render_replica_source_config(flavor)
                 result = self.guest.get_replication_snapshot(
                     snapshot_info, rep_source_config.config_contents)
-                LOG.debug("Got replication snapshot from guest successfully.")
+
+                LOG.info("Finnished getting replication snapshot for "
+                         "instance %s", self.id)
                 return result
             except Exception:
                 LOG.exception("Failed to get replication snapshot from %s.",
@@ -1228,34 +1242,8 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 # Also we check guest state before issuing reboot
                 LOG.debug(str(e))
 
-            # Wait for the mysql stopped.
-            def _datastore_is_offline():
-                self._refresh_datastore_status()
-                return (
-                    self.datastore_status_matches(
-                        rd_instance.ServiceStatuses.SHUTDOWN) or
-                    self.datastore_status_matches(
-                        rd_instance.ServiceStatuses.CRASHED)
-                )
-
-            try:
-                utils.poll_until(
-                    _datastore_is_offline,
-                    sleep_time=3,
-                    time_out=CONF.reboot_time_out
-                )
-            except exception.PollTimeOut:
-                LOG.error("Cannot reboot instance, DB status is %s",
-                          self.datastore_status.status)
-                return
-
-            LOG.debug("The guest service status is %s.",
-                      self.datastore_status.status)
-
             LOG.info("Rebooting instance %s.", self.id)
             self.server.reboot()
-            # Poll nova until instance is active
-            reboot_time_out = CONF.reboot_time_out
 
             def update_server_info():
                 self.refresh_compute_server_info()
@@ -1264,7 +1252,7 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
             utils.poll_until(
                 update_server_info,
                 sleep_time=3,
-                time_out=reboot_time_out)
+                time_out=CONF.reboot_time_out)
 
             # Set the status to PAUSED. The guest agent will reset the status
             # when the reboot completes and MySQL is running.
@@ -1330,8 +1318,8 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
         datastore_status.save()
 
     def upgrade(self, datastore_version):
-        LOG.debug("Upgrading instance %s to new datastore version %s",
-                  self, datastore_version)
+        LOG.info("Upgrading instance %s to new datastore version %s",
+                 self.id, datastore_version)
 
         def server_finished_rebuilding():
             self.refresh_compute_server_info()
@@ -1374,17 +1362,22 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                                 files=injected_files)
             utils.poll_until(
                 server_finished_rebuilding,
-                sleep_time=2, time_out=600)
+                sleep_time=5, time_out=600)
+
             if not self.server_status_matches(['ACTIVE']):
                 raise TroveError(_("Instance %(instance)s failed to "
                                    "upgrade to %(datastore_version)s"),
                                  instance=self,
                                  datastore_version=datastore_version)
 
+            LOG.info('Finished rebuilding server for instance %s', self.id)
+
             self.guest.post_upgrade(upgrade_info)
 
             self.reset_task_status()
-
+            LOG.info("Finished upgrading instance %s to new datastore "
+                     "version %s",
+                     self.id, datastore_version)
         except Exception as e:
             LOG.exception(e)
             err = inst_models.InstanceTasks.BUILDING_ERROR_SERVER
@@ -1417,7 +1410,7 @@ class BackupTasks(object):
     @classmethod
     def delete_files_from_swift(cls, context, filename):
         container = CONF.backup_swift_container
-        client = remote.create_swift_client(context)
+        client = clients.create_swift_client(context)
         obj = client.head_object(container, filename)
         if 'x-static-large-object' in obj:
             # Static large object
@@ -1434,6 +1427,14 @@ class BackupTasks(object):
     @classmethod
     def delete_backup(cls, context, backup_id):
         """Delete backup from swift."""
+        def _delete(backup):
+            backup.deleted = True
+            backup.deleted_at = timeutils.utcnow()
+            # Set datastore_version_id to None so that datastore_version could
+            # be deleted.
+            backup.datastore_version_id = None
+            backup.save()
+
         LOG.info("Deleting backup %s.", backup_id)
         backup = bkup_models.Backup.get_by_id(context, backup_id)
         try:
@@ -1441,11 +1442,11 @@ class BackupTasks(object):
             if filename:
                 BackupTasks.delete_files_from_swift(context, filename)
         except ValueError:
-            backup.delete()
+            _delete(backup)
         except ClientException as e:
             if e.http_status == 404:
                 # Backup already deleted in swift
-                backup.delete()
+                _delete(backup)
             else:
                 LOG.exception("Error occurred when deleting from swift. "
                               "Details: %s", e)
@@ -1454,7 +1455,7 @@ class BackupTasks(object):
                 raise TroveError(_("Failed to delete swift object for backup "
                                    "%s.") % backup_id)
         else:
-            backup.delete()
+            _delete(backup)
         LOG.info("Deleted backup %s successfully.", backup_id)
 
 
@@ -1739,7 +1740,8 @@ class ResizeVolumeAction(object):
                                       'old_volume_size': self.old_size,
                                       'new_size': self.new_size})
 
-        if self.instance.server.status == InstanceStatus.ACTIVE:
+        if self.instance.server.status in [InstanceStatus.ACTIVE,
+                                           InstanceStatus.HEALTHY]:
             self._resize_active_volume()
             self.instance.reset_task_status()
             # send usage event for size reported by cinder
@@ -1755,13 +1757,17 @@ class ResizeVolumeAction(object):
                                       ).notify()
         else:
             self.instance.reset_task_status()
-            msg = _("Failed to resize instance %(id)s volume for server "
-                    "%(server_id)s. The instance must be in state %(state)s "
-                    "not %(inst_state)s.") % {
-                        'id': self.instance.id,
-                        'server_id': self.instance.server.id,
-                        'state': InstanceStatus.ACTIVE,
-                        'inst_state': self.instance.server.status}
+            msg = (
+                "Failed to resize instance %(id)s volume for server "
+                "%(server_id)s. The instance must be in state %(state)s "
+                "not %(inst_state)s." %
+                {
+                    'id': self.instance.id,
+                    'server_id': self.instance.server.id,
+                    'state': [InstanceStatus.ACTIVE, InstanceStatus.HEALTHY],
+                    'inst_state': self.instance.server.status
+                }
+            )
             raise TroveError(msg)
 
 
