@@ -15,6 +15,7 @@
 from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_raises
+from proboscis.asserts import assert_true
 from proboscis.asserts import fail
 from proboscis.decorators import time_out
 from proboscis import SkipTest
@@ -35,7 +36,6 @@ from trove.tests.util import create_dbaas_client
 from trove.tests.util.users import Requirements
 
 
-GROUP = "dbaas.api.backups"
 BACKUP_NAME = 'backup_test'
 BACKUP_DESC = 'test description'
 
@@ -51,8 +51,9 @@ backup_count_prior_to_create = 0
 backup_count_for_instance_prior_to_create = 0
 
 
-@test(depends_on_classes=[WaitForGuestInstallationToFinish],
-      groups=[GROUP, tests.INSTANCES])
+@test(depends_on_groups=[tests.DBAAS_API_INSTANCE_ACTIONS],
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class CreateBackups(object):
 
     @test
@@ -79,7 +80,7 @@ class CreateBackups(object):
         assert_equal('NEW', result.status)
         instance = instance_info.dbaas.instances.get(instance_info.id)
 
-        assert_equal('BACKUP', instance.status)
+        assert_true(instance.status in ['ACTIVE', 'BACKUP', 'HEALTHY'])
         assert_equal(instance_info.dbaas_datastore,
                      result.datastore['type'])
         assert_equal(instance_info.dbaas_datastore_version,
@@ -127,7 +128,7 @@ class BackupRestoreMixin(object):
         # This version just checks the REST API status.
         def result_is_active():
             instance = instance_info.dbaas.instances.get(instance_id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 # If its not ACTIVE, anything but BUILD must be
@@ -141,22 +142,22 @@ class BackupRestoreMixin(object):
                    time_out=TIMEOUT_INSTANCE_CREATE)
 
 
-@test(runs_after=[CreateBackups],
-      groups=[GROUP, tests.INSTANCES])
+@test(depends_on_classes=[CreateBackups],
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class WaitForBackupCreateToFinish(BackupRestoreMixin):
-    """
-        Wait until the backup create is finished.
-    """
+    """Wait until the backup creation is finished."""
 
     @test
     @time_out(TIMEOUT_BACKUP_CREATE)
     def test_backup_created(self):
-        # This version just checks the REST API status.
+        """Wait for the backup to be finished."""
         self.verify_backup(backup_info.id)
 
 
 @test(depends_on=[WaitForBackupCreateToFinish],
-      groups=[GROUP, tests.INSTANCES])
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class ListBackups(object):
 
     @test
@@ -188,7 +189,7 @@ class ListBackups(object):
     def test_backup_list_filter_different_datastore(self):
         """Test list backups and filter by datastore."""
         result = instance_info.dbaas.backups.list(
-            datastore='Test_Datastore_1')
+            datastore=CONFIG.dbaas_datastore_name_no_versions)
         # There should not be any backups for this datastore
         assert_equal(0, len(result))
 
@@ -244,7 +245,8 @@ class ListBackups(object):
 
 @test(runs_after=[ListBackups],
       depends_on=[WaitForBackupCreateToFinish],
-      groups=[GROUP, tests.INSTANCES])
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class IncrementalBackups(BackupRestoreMixin):
 
     @test
@@ -271,9 +273,10 @@ class IncrementalBackups(BackupRestoreMixin):
         assert_equal(backup_info.id, incremental_info.parent_id)
 
 
-@test(groups=[GROUP, tests.INSTANCES])
+@test(groups=[tests.DBAAS_API_BACKUPS],
+      depends_on_classes=[IncrementalBackups],
+      enabled=CONFIG.swift_enabled)
 class RestoreUsingBackup(object):
-
     @classmethod
     def _restore(cls, backup_ref):
         restorePoint = {"backupRef": backup_ref}
@@ -291,22 +294,23 @@ class RestoreUsingBackup(object):
 
     @test(depends_on=[IncrementalBackups])
     def test_restore_incremental(self):
+        """Restore from incremental backup."""
         global incremental_restore_instance_id
         incremental_restore_instance_id = self._restore(incremental_info.id)
 
 
-@test(depends_on_classes=[WaitForGuestInstallationToFinish],
-      runs_after_groups=['dbaas.api.configurations.define'],
-      groups=[GROUP, tests.INSTANCES])
+@test(depends_on_classes=[RestoreUsingBackup],
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class WaitForRestoreToFinish(object):
-
     @classmethod
     def _poll(cls, instance_id_to_poll):
         """Shared "instance restored" test logic."""
+
         # This version just checks the REST API status.
         def result_is_active():
             instance = instance_info.dbaas.instances.get(instance_id_to_poll)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 # If its not ACTIVE, anything but BUILD must be
@@ -319,10 +323,7 @@ class WaitForRestoreToFinish(object):
         poll_until(result_is_active, time_out=TIMEOUT_INSTANCE_CREATE,
                    sleep_time=10)
 
-    """
-        Wait until the instance is finished restoring from incremental backup.
-    """
-    @test(depends_on=[RestoreUsingBackup.test_restore_incremental])
+    @test
     def test_instance_restored_incremental(self):
         try:
             self._poll(incremental_restore_instance_id)
@@ -330,8 +331,9 @@ class WaitForRestoreToFinish(object):
             fail('Timed out')
 
 
-@test(enabled=(not CONFIG.fake_mode),
-      groups=[GROUP, tests.INSTANCES])
+@test(enabled=(not CONFIG.fake_mode and CONFIG.swift_enabled),
+      depends_on_classes=[WaitForRestoreToFinish],
+      groups=[tests.DBAAS_API_BACKUPS])
 class VerifyRestore(object):
 
     @classmethod
@@ -345,8 +347,7 @@ class VerifyRestore(object):
 
         poll_until(db_is_found, time_out=60 * 10, sleep_time=10)
 
-    @test(depends_on=[WaitForRestoreToFinish.
-          test_instance_restored_incremental])
+    @test
     def test_database_restored_incremental(self):
         try:
             self._poll(incremental_restore_instance_id, incremental_db)
@@ -356,7 +357,8 @@ class VerifyRestore(object):
             fail('Timed out')
 
 
-@test(groups=[GROUP, tests.INSTANCES])
+@test(groups=[tests.DBAAS_API_BACKUPS], enabled=CONFIG.swift_enabled,
+      depends_on_classes=[VerifyRestore])
 class DeleteRestoreInstance(object):
 
     @classmethod
@@ -376,7 +378,7 @@ class DeleteRestoreInstance(object):
         assert_raises(exceptions.NotFound, instance_info.dbaas.instances.get,
                       instance_id)
 
-    @test(runs_after=[VerifyRestore.test_database_restored_incremental])
+    @test
     def test_delete_restored_instance_incremental(self):
         try:
             self._delete(incremental_restore_instance_id)
@@ -384,10 +386,10 @@ class DeleteRestoreInstance(object):
             fail('Timed out')
 
 
-@test(runs_after=[DeleteRestoreInstance],
-      groups=[GROUP, tests.INSTANCES])
+@test(depends_on_classes=[DeleteRestoreInstance],
+      groups=[tests.DBAAS_API_BACKUPS],
+      enabled=CONFIG.swift_enabled)
 class DeleteBackups(object):
-
     @test
     def test_backup_delete_not_found(self):
         """Test delete unknown backup."""
@@ -432,7 +434,8 @@ class DeleteBackups(object):
 
 
 @test(depends_on=[WaitForGuestInstallationToFinish],
-      runs_after=[DeleteBackups])
+      runs_after=[DeleteBackups],
+      enabled=CONFIG.swift_enabled)
 class FakeTestHugeBackupOnSmallInstance(BackupRestoreMixin):
 
     report = CONFIG.get_report()
