@@ -34,13 +34,12 @@ import six
 from troveclient.compat import exceptions
 
 from trove.common.utils import poll_until
-from trove.tests.api.backups import RestoreUsingBackup
+from trove import tests
 from trove.tests.api.instances import assert_unprocessable
 from trove.tests.api.instances import instance_info
 from trove.tests.api.instances import InstanceTestInfo
 from trove.tests.api.instances import TIMEOUT_INSTANCE_CREATE
 from trove.tests.api.instances import TIMEOUT_INSTANCE_DELETE
-from trove.tests.api.instances import WaitForGuestInstallationToFinish
 from trove.tests.config import CONFIG
 from trove.tests.util.check import AttrCheck
 from trove.tests.util.check import CollectionCheck
@@ -49,9 +48,6 @@ from trove.tests.util import create_dbaas_client
 from trove.tests.util.mysql import create_mysql_connection
 from trove.tests.util.users import Requirements
 
-
-GROUP = "dbaas.api.configurations"
-GROUP_CONFIG_DEFINE = "dbaas.api.configurations.define"
 CONFIG_NAME = "test_configuration"
 CONFIG_DESC = "configuration description"
 
@@ -77,11 +73,12 @@ def _is_valid_timestamp(time_string):
 
 # helper methods to validate configuration is applied to instance
 def _execute_query(host, user_name, password, query):
-    print(host, user_name, password, query)
+    print("Starting to query database, host: %s, user: %s, password: %s, "
+          "query: %s" % (host, user_name, password, query))
+
     with create_mysql_connection(host, user_name, password) as db:
         result = db.execute(query)
         return result
-    assert_true(False, "something went wrong in the sql connection")
 
 
 def _get_address(instance_id):
@@ -178,9 +175,8 @@ class ConfigurationsTestBase(object):
         return datastore_test_configs.get("configurations", {})
 
 
-@test(depends_on_classes=[WaitForGuestInstallationToFinish],
-      runs_after=[RestoreUsingBackup],
-      groups=[GROUP, GROUP_CONFIG_DEFINE])
+@test(depends_on_groups=[tests.DBAAS_API_BACKUPS],
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class CreateConfigurations(ConfigurationsTestBase):
 
     @test
@@ -314,13 +310,13 @@ class CreateConfigurations(ConfigurationsTestBase):
         assert_equal(resp.status, 200)
 
 
-@test(runs_after=[CreateConfigurations],
-      groups=[GROUP, GROUP_CONFIG_DEFINE])
+@test(depends_on_classes=[CreateConfigurations],
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class AfterConfigurationsCreation(ConfigurationsTestBase):
 
     @test
     def test_assign_configuration_to_invalid_instance(self):
-        # test assigning to an instance that does not exist
+        """test assigning to an instance that does not exist"""
         invalid_id = "invalid-inst-id"
         try:
             instance_info.dbaas.instances.modify(invalid_id,
@@ -331,7 +327,7 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
 
     @test
     def test_assign_configuration_to_valid_instance(self):
-        # test assigning a configuration to an instance
+        """test assigning a configuration to an instance"""
         print("instance_info.id: %s" % instance_info.id)
         print("configuration_info: %s" % configuration_info)
         print("configuration_info.id: %s" % configuration_info.id)
@@ -341,36 +337,9 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 202)
 
-    @test
-    def test_assign_name_to_instance_using_patch(self):
-        # test assigning a name to an instance
-        new_name = 'new_name_1'
-        report = CONFIG.get_report()
-        report.log("instance_info.id: %s" % instance_info.id)
-        report.log("instance name:%s" % instance_info.name)
-        report.log("instance new name:%s" % new_name)
-        instance_info.dbaas.instances.edit(instance_info.id, name=new_name)
-        assert_equal(202, instance_info.dbaas.last_http_code)
-        check = instance_info.dbaas.instances.get(instance_info.id)
-        assert_equal(200, instance_info.dbaas.last_http_code)
-        assert_equal(check.name, new_name)
-        # Restore instance name
-        instance_info.dbaas.instances.edit(instance_info.id,
-                                           name=instance_info.name)
-        assert_equal(202, instance_info.dbaas.last_http_code)
-
-    @test
-    def test_assign_configuration_to_invalid_instance_using_patch(self):
-        # test assign config group to an invalid instance
-        invalid_id = "invalid-inst-id"
-        assert_raises(exceptions.NotFound,
-                      instance_info.dbaas.instances.edit,
-                      invalid_id, configuration=configuration_info.id)
-
     @test(depends_on=[test_assign_configuration_to_valid_instance])
     def test_assign_configuration_to_instance_with_config(self):
-        # test assigning a configuration to an instance that
-        # already has an assigned configuration
+        """test assigning a configuration to an instance conflicts"""
         config_id = configuration_info.id
         assert_raises(exceptions.BadRequest,
                       instance_info.dbaas.instances.modify, instance_info.id,
@@ -379,17 +348,18 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
     @test(depends_on=[test_assign_configuration_to_valid_instance])
     @time_out(30)
     def test_get_configuration_details_from_instance_validation(self):
-        # validate that the configuration was applied correctly to the instance
+        """validate the configuration after attaching"""
         print("instance_info.id: %s" % instance_info.id)
         inst = instance_info.dbaas.instances.get(instance_info.id)
         configuration_id = inst.configuration['id']
         print("configuration_info: %s" % configuration_id)
-        assert_not_equal(None, inst.configuration['id'])
+        assert_not_equal(None, configuration_id)
         _test_configuration_is_applied_to_instance(instance_info,
                                                    configuration_id)
 
+    @test(depends_on=[test_get_configuration_details_from_instance_validation])
     def test_configurations_get(self):
-        # test that the instance shows up on the assigned configuration
+        """test that the instance shows up on the assigned configuration"""
         result = instance_info.dbaas.configurations.get(configuration_info.id)
         assert_equal(configuration_info.id, result.id)
         assert_equal(configuration_info.name, result.name)
@@ -453,8 +423,8 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
                       configuration_info.id)
 
 
-@test(runs_after=[AfterConfigurationsCreation],
-      groups=[GROUP, GROUP_CONFIG_DEFINE])
+@test(depends_on_classes=[AfterConfigurationsCreation],
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class ListConfigurations(ConfigurationsTestBase):
 
     @test
@@ -519,7 +489,7 @@ class ListConfigurations(ConfigurationsTestBase):
         def result_is_not_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return False
             else:
                 return True
@@ -528,7 +498,6 @@ class ListConfigurations(ConfigurationsTestBase):
         instance = instance_info.dbaas.instances.get(instance_info.id)
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 200)
-        print(instance.status)
         assert_equal('RESTART_REQUIRED', instance.status)
 
     @test(depends_on=[test_waiting_for_instance_in_restart_required])
@@ -541,7 +510,7 @@ class ListConfigurations(ConfigurationsTestBase):
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 assert_equal("REBOOT", instance.status)
@@ -571,13 +540,13 @@ class ListConfigurations(ConfigurationsTestBase):
         assert_equal(list_config[0].updated, details_config.updated)
 
 
-@test(runs_after=[ListConfigurations],
-      groups=[GROUP, GROUP_CONFIG_DEFINE])
+@test(depends_on_classes=[ListConfigurations],
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class StartInstanceWithConfiguration(ConfigurationsTestBase):
 
     @test
     def test_start_instance_with_configuration(self):
-        # test that a new instance will apply the configuration on create
+        """test that a new instance will apply the configuration on create"""
         global configuration_instance
         databases = []
         databases.append({"name": "firstdbconfig", "character_set": "latin2",
@@ -614,19 +583,18 @@ class StartInstanceWithConfiguration(ConfigurationsTestBase):
 
 
 @test(depends_on_classes=[StartInstanceWithConfiguration],
-      runs_after_groups=['dbaas.api.backups'],
-      groups=[GROUP])
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class WaitForConfigurationInstanceToFinish(ConfigurationsTestBase):
 
     @test
     @time_out(TIMEOUT_INSTANCE_CREATE)
     def test_instance_with_configuration_active(self):
-        # wait for the instance to become active
+        """wait for the instance created with configuration"""
 
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
                 configuration_instance.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 assert_equal("BUILD", instance.status)
@@ -637,15 +605,16 @@ class WaitForConfigurationInstanceToFinish(ConfigurationsTestBase):
     @test(depends_on=[test_instance_with_configuration_active])
     @time_out(30)
     def test_get_configuration_details_from_instance_validation(self):
-        # validate that the configuration was applied correctly to the instance
+        """Test configuration is applied correctly to the instance."""
         inst = instance_info.dbaas.instances.get(configuration_instance.id)
         configuration_id = inst.configuration['id']
-        assert_not_equal(None, inst.configuration['id'])
+        assert_not_equal(None, configuration_id)
         _test_configuration_is_applied_to_instance(configuration_instance,
                                                    configuration_id)
 
 
-@test(runs_after=[WaitForConfigurationInstanceToFinish], groups=[GROUP])
+@test(depends_on=[WaitForConfigurationInstanceToFinish],
+      groups=[tests.DBAAS_API_CONFIGURATIONS])
 class DeleteConfigurations(ConfigurationsTestBase):
 
     @before_class
@@ -664,18 +633,19 @@ class DeleteConfigurations(ConfigurationsTestBase):
     @after_class(always_run=True)
     def tearDown(self):
         # need to "undelete" the parameter that was deleted from the mgmt call
-        ds = instance_info.dbaas_datastore
-        ds_v = instance_info.dbaas_datastore_version
-        version = instance_info.dbaas.datastore_versions.get(
-            ds, ds_v)
-        client = instance_info.dbaas_admin.mgmt_configs
-        print(self.config_parameter_dict)
-        client.create(version.id,
-                      self.config_parameter_dict['name'],
-                      self.config_parameter_dict['restart_required'],
-                      self.config_parameter_dict['type'],
-                      self.config_parameter_dict['max'],
-                      self.config_parameter_dict['min'])
+        if instance_info.dbaas:
+            ds = instance_info.dbaas_datastore
+            ds_v = instance_info.dbaas_datastore_version
+            version = instance_info.dbaas.datastore_versions.get(
+                ds, ds_v)
+            client = instance_info.dbaas_admin.mgmt_configs
+            print(self.config_parameter_dict)
+            client.create(version.id,
+                          self.config_parameter_dict['name'],
+                          self.config_parameter_dict['restart_required'],
+                          self.config_parameter_dict['type'],
+                          self.config_parameter_dict['max'],
+                          self.config_parameter_dict['min'])
 
     @test
     def test_delete_invalid_configuration_not_found(self):
@@ -715,7 +685,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
     @test(depends_on=[test_unable_delete_instance_configurations])
     @time_out(30)
     def test_unassign_configuration_from_instances(self):
-        # test to unassign configuration from instance
+        """test to unassign configuration from instance"""
         instance_info.dbaas.instances.modify(configuration_instance.id,
                                              configuration="")
         resp, body = instance_info.dbaas.client.last_response
@@ -751,7 +721,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
 
     @test(depends_on=[test_assign_in_wrong_state])
     def test_no_instances_on_configuration(self):
-        # test there is no configuration on the instance after unassigning
+        """test_no_instances_on_configuration"""
         result = instance_info.dbaas.configurations.get(configuration_info.id)
         assert_equal(configuration_info.id, result.id)
         assert_equal(configuration_info.name, result.name)
@@ -763,10 +733,11 @@ class DeleteConfigurations(ConfigurationsTestBase):
     @test(depends_on=[test_unassign_configuration_from_instances])
     @time_out(120)
     def test_restart_service_after_unassign_return_active(self):
+        """test_restart_service_after_unassign_return_active"""
         def result_is_not_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return False
             else:
                 return True
@@ -775,16 +746,14 @@ class DeleteConfigurations(ConfigurationsTestBase):
         config = instance_info.dbaas.configurations.list()
         print(config)
         instance = instance_info.dbaas.instances.get(instance_info.id)
-        print(instance.__dict__)
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 200)
-        print(instance.status)
         assert_equal('RESTART_REQUIRED', instance.status)
 
     @test(depends_on=[test_restart_service_after_unassign_return_active])
     @time_out(120)
     def test_restart_service_should_return_active(self):
-        # test that after restarting the instance it becomes active
+        """test that after restarting the instance it becomes active"""
         instance_info.dbaas.instances.restart(instance_info.id)
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 202)
@@ -792,7 +761,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 assert_equal("REBOOT", instance.status)
@@ -801,7 +770,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
 
     @test(depends_on=[test_restart_service_should_return_active])
     def test_assign_config_and_name_to_instance_using_patch(self):
-        # test assigning a configuration and name to an instance
+        """test_assign_config_and_name_to_instance_using_patch"""
         new_name = 'new_name'
         report = CONFIG.get_report()
         report.log("instance_info.id: %s" % instance_info.id)
@@ -834,7 +803,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 assert_equal("REBOOT", instance.status)
@@ -849,7 +818,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
 
     @test(runs_after=[test_assign_config_and_name_to_instance_using_patch])
     def test_unassign_configuration_after_patch(self):
-        # remove the configuration from the instance
+        """Remove the configuration from the instance"""
         instance_info.dbaas.instances.edit(instance_info.id,
                                            remove_configuration=True)
         assert_equal(202, instance_info.dbaas.last_http_code)
@@ -863,11 +832,12 @@ class DeleteConfigurations(ConfigurationsTestBase):
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
                 instance_info.id)
-            if instance.status == "ACTIVE":
+            if instance.status in CONFIG.running_status:
                 return True
             else:
                 assert_equal("REBOOT", instance.status)
                 return False
+
         poll_until(result_is_active)
         result = instance_info.dbaas.configurations.get(configuration_info.id)
         assert_equal(result.instance_count, 0)
@@ -885,8 +855,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
 
     @test(runs_after=[test_unassign_configuration_after_patch])
     def test_delete_unassigned_configuration(self):
-        # test that we can delete the configuration after no instances are
-        # assigned to it any longer
+        """test_delete_unassigned_configuration"""
         instance_info.dbaas.configurations.delete(configuration_info.id)
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 202)
@@ -894,8 +863,7 @@ class DeleteConfigurations(ConfigurationsTestBase):
     @test(depends_on=[test_delete_unassigned_configuration])
     @time_out(TIMEOUT_INSTANCE_DELETE)
     def test_delete_configuration_instance(self):
-        # test that we can delete the instance even though there is a
-        # configuration applied to the instance
+        """test_delete_configuration_instance"""
         instance_info.dbaas.instances.delete(configuration_instance.id)
         assert_equal(202, instance_info.dbaas.last_http_code)
 
