@@ -78,7 +78,6 @@ class TestConfig(object):
             'dbaas_datastore_version': "5.5",
             'dbaas_datastore_version_id': "b00000b0-00b0-0b00-00b0-"
                                           "000b000000bb",
-            'dbaas_inactive_datastore_version': "mysql_inactive_version",
             'instance_create_time': 16 * 60,
             'mysql_connection_method': {"type": "direct"},
             'typical_nova_image_name': None,
@@ -123,6 +122,9 @@ class TestConfig(object):
                 "volume_support": True,
             },
             "redis": {"volume_support": False},
+            "swift_enabled": True,
+            "trove_mgmt_network": "trove-mgmt",
+            "running_status": ["ACTIVE", "HEALTHY"],
         }
         self._frozen_values = FrozenDict(self._values)
         self._users = None
