@@ -92,9 +92,9 @@ class FakeGuest(object):
         LOG.debug("Updating attributes")
         self._check_username(username)
         if (username, hostname) not in self.users:
-                raise rd_exception.UserNotFound(
-                    "User %s@%s cannot be found on the instance."
-                    % (username, hostname))
+            raise rd_exception.UserNotFound(
+                "User %s@%s cannot be found on the instance."
+                % (username, hostname))
         new_name = user_attrs.get('name')
         new_host = user_attrs.get('host')
         new_password = user_attrs.get('password')
@@ -238,15 +238,15 @@ class FakeGuest(object):
             if instance_name.endswith('GUEST_ERROR'):
                 status.status = rd_instance.ServiceStatuses.FAILED
             else:
-                status.status = rd_instance.ServiceStatuses.RUNNING
+                status.status = rd_instance.ServiceStatuses.HEALTHY
             status.save()
             AgentHeartBeat.create(instance_id=self.id)
         eventlet.spawn_after(3.5, update_db)
 
-    def _set_task_status(self, new_status='RUNNING'):
+    def _set_task_status(self, new_status='HEALTHY'):
         from trove.instance.models import InstanceServiceStatus
         print("Setting status to %s" % new_status)
-        states = {'RUNNING': rd_instance.ServiceStatuses.RUNNING,
+        states = {'HEALTHY': rd_instance.ServiceStatuses.HEALTHY,
                   'SHUTDOWN': rd_instance.ServiceStatuses.SHUTDOWN,
                   }
         status = InstanceServiceStatus.find_by(instance_id=self.id)
@@ -259,7 +259,7 @@ class FakeGuest(object):
         # take a nap.
         print("Sleeping for a second.")
         time.sleep(1)
-        self._set_task_status('RUNNING')
+        self._set_task_status('HEALTHY')
 
     def reset_configuration(self, config):
         # There's nothing to do here, since there is no config to update.
@@ -267,7 +267,7 @@ class FakeGuest(object):
 
     def start_db_with_conf_changes(self, config_contents):
         time.sleep(2)
-        self._set_task_status('RUNNING')
+        self._set_task_status('HEALTHY')
 
     def stop_db(self, do_not_start_on_reboot=False):
         self._set_task_status('SHUTDOWN')
