@@ -78,15 +78,17 @@ ZIP = "gzip"
 UNZIP = "gzip -d -c"
 ENCRYPT = "openssl enc -aes-256-cbc -salt -pass pass:default_aes_cbc_key"
 DECRYPT = "openssl enc -d -aes-256-cbc -salt -pass pass:default_aes_cbc_key"
-XTRA_BACKUP_RAW = ("sudo innobackupex --stream=xbstream %(extra_opts)s "
-                   " --user=os_admin --password=password --host=127.0.0.1"
+XTRA_BACKUP_RAW = ("sudo innobackupex --stream=xbstream %(extra_opts)s"
+                   " --user=os_admin --password=password --host=localhost"
+                   " --socket=/var/run/mysqld/mysqld.sock"
                    " /var/lib/mysql/data 2>/tmp/innobackupex.log")
 XTRA_BACKUP = XTRA_BACKUP_RAW % {'extra_opts': ''}
 XTRA_BACKUP_EXTRA_OPTS = XTRA_BACKUP_RAW % {'extra_opts': '--no-lock'}
 XTRA_BACKUP_INCR = ('sudo innobackupex --stream=xbstream'
                     ' --incremental --incremental-lsn=%(lsn)s'
-                    ' %(extra_opts)s '
-                    ' --user=os_admin --password=password --host=127.0.0.1'
+                    ' %(extra_opts)s'
+                    ' --user=os_admin --password=password --host=localhost'
+                    ' --socket=/var/run/mysqld/mysqld.sock'
                     ' /var/lib/mysql/data'
                     ' 2>/tmp/innobackupex.log')
 SQLDUMP_BACKUP_RAW = ("mysqldump --all-databases %(extra_opts)s "
@@ -470,7 +472,7 @@ class GuestAgentBackupTest(trove_testtools.TestCase):
         backupBase.BackupRunner.encrypt_key = CRYPTO_KEY
         RunnerClass = utils.import_class(BACKUP_DB2_CLS)
         bkp = RunnerClass(12345)        # this is not db2 backup filename
-        self.assertIsNotNone(12345)     # look into this
+        self.assertIsNotNone(bkp)     # look into this
         self.assertEqual(
             DB2BACKUP_CMD + PIPE + ZIP + PIPE + ENCRYPT, bkp.command)
         self.assertIn("gz.enc", bkp.manifest)
