@@ -123,8 +123,10 @@ class ManagerTest(trove_testtools.TestCase):
         super(ManagerTest, self).tearDown()
 
     def test_update_status(self):
+        self.manager._status.is_installed = True
+        self.manager._status._is_restarting = False
         self.manager.update_status(self.context)
-        self.manager.status.update.assert_any_call()
+        self.assertTrue(self.manager.status.set_status.called)
 
     def test_guest_log_list(self):
         log_list = self.manager.guest_log_list(self.context)
@@ -257,7 +259,7 @@ class ManagerTest(trove_testtools.TestCase):
 
     def assert_guest_log_status(self, original_status, new_status,
                                 expected_final_status):
-        gl_cache = self.manager.guest_log_cache
+        gl_cache = self.manager.get_guest_log_cache()
         gl_cache[self.log_name_sys]._status = original_status
         self.manager.set_guest_log_status(new_status, self.log_name_sys)
         assert_equal(gl_cache[self.log_name_sys].status, expected_final_status,
